@@ -11,7 +11,7 @@ class OffersDashboardConfig(apps.OffersDashboardConfig):
 
     def ready(self):
         super().ready()
-        self.flash_sale_create_view = get_class('dashboard.offers.views', 'FlashSaleCreateView')
+        self.flash_sale_create_view = get_class('ms_oscar_flash_offer.dashboard.offers.views', 'FlashSaleCreateView')
 
     def get_urls(self):
         urls = [
